# Templates for Macros
The `macros` template tags (`regulations.templatetags.macros`) allow us to
write common tasks, particularly around linking, more concisely. This
directory contains the associated templates for those macros. All file names
here should match the appropriate macro name (though that's not a hard
requirement).
